# RCSid:
#	$Id: Makefile.inc,v 1.70 2010/01/05 08:36:45 sjg Exp $
#
#	@(#) Copyright (c) 1995-2009 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

.ifndef _top_inc_
_top_inc_=yes

.if defined(SB)
SRCTOP ?= ${SB}
.endif
# this needs latest bmake
.if !defined(SRCTOP)
.if defined(.PARSEDIR)
SRCTOP != cd ${.PARSEDIR}; pwd
.endif
.endif
.if !defined(SRCTOP)
.error ${.MAKE} cannot set SRCTOP automagically.
.endif

RELDIR := ${.CURDIR:S,${SRCTOP}/,,}
RELTOP := ${RELDIR:C,[^/]+,..,g}

# this lets them override things
.-include "Makefile.local.inc"


prefix ?= /usr/local
libprefix ?= ${prefix}

.include <own.mk>

CFLAGS+= -I. -I${.CURDIR} -I${SRCTOP}/include

BINDIR = ${prefix}/bin
SBINDIR = ${prefix}/sbin
LIBDIR = ${prefix}/lib
LIBEXECDIR = ${prefix}/libexec
MANDIR = ${prefix}/man
ETCDIR = ${prefix}/etc
INCDIR = ${prefix}/include

# work out our parent dir.
PDIR=${.CURDIR:H:T}
.if (${PDIR} == "sbin") || (${PDIR} == "lib") || (${PDIR} == "libexec") || (${PDIR} == "etc")
BINDIR = ${prefix}/${PDIR}
.endif
.ifdef PROG
.if (${PDIR} == "libexec")
MAN ?= ${PROG}.8
.else
MAN ?= ${PROG}.1
.endif
.endif
.ifdef LIB
MAN ?= ${SRCS:T:.c=.3}
.endif
ROOT_GROUP ?= wheel
BINOWN ?= root
BINGRP ?= ${ROOT_GROUP}
LIBOWN ?= root
LIBGRP ?= ${ROOT_GROUP}
LIBMODE = 644
BINMODE = 755
SCRIPTS ?= ${SRCTOP}/scripts
INSTALL = ${SCRIPTS}/install-sh

BININSTALL_FLAGS = ${COPY} ${STRIP} -m ${BINMODE}
LIBINSTALL_FLAGS = ${COPY} -m ${LIBMODE}
.if !empty(BINOWN)
BININSTALL_FLAGS += -o ${BINOWN} -g ${BINGRP}
.endif
.if !empty(LIBOWN)
LIBINSTALL_FLAGS += -o ${LIBOWN} -g ${LIBGRP}
.endif

STRIP ?=
COPY ?=

CFLAGS += ${DBG} 

CMT2DOC ?= cmt2doc.pl
.if !exists(${CMT2DOC})
CMT2DOC := ${CMT2DOC:${M_whence}}
.if exists(${CMT2DOC})
.export CMT2DOC
.else
EXTRACT_MAN=no
.endif
.endif

# one or more of these might exist
.-include "Makefile.${MACHINE}.inc"
.-include "Makefile.${HOST_OS}.inc"
.-include "Makefile.${host_os}.inc"
.-include "Makefile.${HOST_TARGET}.inc"

CONFDIR ?= ${OBJTOP}/conf
.if exists(${CONFDIR}/Makefile.inc)
.include "${CONFDIR}/Makefile.inc"
CPPFLAGS += -I${CONFDIR}
.endif

# lots of systems no longer define unix, but as far as old s/w
# is concerned they still are, and we don't support anything else.
CPPFLAGS+= -Dunix 

DBG ?= -g

USE_DPADD_MK ?= yes

# some standard stuff for building other peoples packages.
.if exists(${.CURDIR}/src)
.PATH: ${.CURDIR}/src
CPPFLAGS += -I. -I${.CURDIR} -I${.CURDIR}/src
.elif exists(${.CURDIR:H}/dist)
.if exists(${.CURDIR:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H}/dist/${.CURDIR:T}
CPPFLAGS += -I${.CURDIR:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H}/dist
.endif
CPPFLAGS += -I${.CURDIR:H}/dist
.elif exists(${.CURDIR:H:H}/dist)
.if exists(${.CURDIR:H:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H:H}/dist/${.CURDIR:T}
CPPFLAGS += -I${.CURDIR:H:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H:H}/dist
.endif
CPPFLAGS += -I${.CURDIR:H:H}/dist
.endif

.ifdef SUBDIR
# make sure destination exists
beforeinstall:
	test -d ${DESTDIR}${BINDIR} || ${INSTALL} -m 775 -d ${DESTDIR}${BINDIR}
.endif

HOST_LIBS += crypt crypto ssl util termcap

.ifdef NO_FWTK
USE_FWTK = no
LIBFWTK =
CFLAGS += -DNO_FWTK
.endif

.endif	# _top_inc_
